@@ -3,7 +3,7 @@
 set -euo pipefail
 
 cat << EOF
- _______  _______  __   __  ___   __    _ 
+ _______  _______  __   __  ___   __    _
 |   _   ||       ||  | |  ||   | |  |  | |
 |  |_|  ||_     _||  | |  ||   | |   |_| |
 |       |  |   |  |  |_|  ||   | |       |
@@ -22,6 +22,14 @@ Please file an issue if you encounter any problems!
 
 EOF
 
+if ! command -v curl &> /dev/null; then
+    echo "curl not installed. Please install curl."
+    exit
+elif ! command -v sed &> /dev/null; then
+    echo "sed not installed. Please install sed."
+    exit
+fi
+
 LATEST_RELEASE=$(curl -L -s -H 'Accept: application/json' https://github.com/ellie/atuin/releases/latest)
 # Allow sed; sometimes it's more readable than ${variable//search/replace}
 # shellcheck disable=SC2001
@@ -29,22 +37,28 @@ LATEST_VERSION=$(echo "$LATEST_RELEASE" | sed -e 's/.*"tag_name":"\([^"]*\)".*/\
 
 __atuin_install_arch(){
 	echo "Arch Linux detected!"
-	echo "Attempting AUR install"
 
-	if command -v yaourt &> /dev/null; then
-		echo "Found yaourt"
-		yaourt -S atuin
-	elif command -v yay &> /dev/null; then
-		echo "Found yay"
-		yay -S atuin
-	elif command -v pakku &> /dev/null; then
-		echo "Found pakku"
-		pakku -S atuin
-	elif command -v pamac &> /dev/null; then
-		echo "Found pamac"
-		pamac install atuin
+	if command -v pacman &> /dev/null
+	then
+		echo "Installing with pacman"
+		sudo pacman -S atuin
 	else
-		echo "Failed to install atuin! Please try manually: https://aur.archlinux.org/packages/atuin/"
+		echo "Attempting AUR install"
+		if command -v yaourt &> /dev/null; then
+			echo "Found yaourt"
+			yaourt -S atuin
+		elif command -v yay &> /dev/null; then
+			echo "Found yay"
+			yay -S atuin
+		elif command -v pakku &> /dev/null; then
+			echo "Found pakku"
+			pakku -S atuin
+		elif command -v pamac &> /dev/null; then
+			echo "Found pamac"
+			pamac install atuin
+		else
+			echo "Failed to install atuin! Please try manually: https://aur.archlinux.org/packages/atuin-git/"
+		fi
 	fi
 
 }
@@ -54,9 +68,13 @@ __atuin_install_ubuntu(){
 	# TODO: select correct AARCH too
 	ARTIFACT_URL="https://github.com/ellie/atuin/releases/download/$LATEST_VERSION/atuin_${LATEST_VERSION//v/}_amd64.deb"
 
-	TEMP_DEB="$(mktemp)" &&
-	wget -O "$TEMP_DEB" "$ARTIFACT_URL"
-	sudo dpkg -i "$TEMP_DEB"
+	TEMP_DEB="$(mktemp)".deb &&
+	curl -Lo "$TEMP_DEB" "$ARTIFACT_URL"
+	if command -v sudo &> /dev/null; then
+		sudo apt install "$TEMP_DEB"
+	else
+		su -l -c "apt install '$TEMP_DEB'"
+	fi
 	rm -f "$TEMP_DEB"
 }
 
@@ -69,7 +87,7 @@ __atuin_install_linux(){
     else
         if ! command -v lsb_release &> /dev/null; then
             echo "lsb_release could not be found, unable to determine your distribution"
-            echo "If you are using Arch, please get lsb_release from AUR"
+            echo "If you are using Arch Linux, please get community/lsb-release"
             exit 1
         fi
         OS=$(lsb_release -i | awk '{ print $3 }')
@@ -77,7 +95,7 @@ __atuin_install_linux(){
 
 	if [ "$OS" == "Arch" ] || [ "$OS" == "ManjaroLinux" ]; then
 		__atuin_install_arch
-    elif [ "$OS" == "Ubuntu" ] || [ "$OS" == "Debian" ] || [ "$OS" == "Linuxmint" ] || [ "$OS" == "Parrot" ] || [ "$OS" == "Kali" ] || [ "$OS" == "Elementary" ]; then
+    elif [ "$OS" == "Ubuntu" ] || [ "$OS" == "UbuntuWSL" ] || [ "$OS" == "Debian" ] || [ "$OS" == "Linuxmint" ] || [ "$OS" == "Parrot" ] || [ "$OS" == "Kali" ] || [ "$OS" == "Elementary" ] || [ "$OS" == "Pop" ]; then
 		__atuin_install_ubuntu
 	else
 		# TODO: download a binary or smth
@@ -150,10 +168,10 @@ esac
 # TODO: Check which shell is in use
 # Use of single quotes around $() is intentional here
 # shellcheck disable=SC2016
-printf '\neval "$(atuin init zsh)"' >> ~/.zshrc
+printf '\neval "$(atuin init zsh)"\n' >> ~/.zshrc
 
 curl https://raw.githubusercontent.com/rcaloras/bash-preexec/master/bash-preexec.sh -o ~/.bash-preexec.sh
-printf '\n[[ -f ~/.bash-preexec.sh ]] && source ~/.bash-preexec.sh' >> ~/.bashrc
+printf '\n[[ -f ~/.bash-preexec.sh ]] && source ~/.bash-preexec.sh\n' >> ~/.bashrc
 # Use of single quotes around $() is intentional here
 # shellcheck disable=SC2016
 echo 'eval "$(atuin init bash)"' >> ~/.bashrc
